@@ -1,10 +1,10 @@
-# $Id: Handel.pm 921 2005-11-15 02:58:20Z claco $
+# $Id: Handel.pm 1012 2005-12-09 00:59:13Z claco $
 package Handel;
 use strict;
 use warnings;
 use vars qw($VERSION);
 
-$VERSION = '0.28';
+$VERSION = '0.29';
 
 BEGIN {
     use Handel::ConfigReader;
@@ -13,7 +13,7 @@ BEGIN {
 
     my $uuidsub;
 
-    if (eval{require APR::UUID}) {
+    if ($^O ne 'openbsd' && eval{require APR::UUID}) {
         $uuidsub = sub {
             return APR::UUID->new->format;
         };
